==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/c7/c7d0ae11319d70d7feb158d13c03c775.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/ProcessSignal/Exception/SignalCaughtException.php */
class __TwigTemplate_df57d0094493f3039b37e0d56525a0a8 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\ProcessSignal\\Exception;

use Mautic\\CoreBundle\\ProcessSignal\\ProcessSignalService;

class SignalCaughtException extends \\Exception
{
    public function __construct(int \$signal = ProcessSignalService::SIGTERM)
    {
        parent::__construct(sprintf('Signal received: \"%d\"', \$signal), \$signal);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/ProcessSignal/Exception/SignalCaughtException.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/ProcessSignal/Exception/SignalCaughtException.php", "/var/www/mautic-ktn/app/bundles/CoreBundle/ProcessSignal/Exception/SignalCaughtException.php");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/c7/c7d0ae11319d70d7feb158d13c03c775.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/ProcessSignal/Exception/SignalCaughtException.php */
class __TwigTemplate_df57d0094493f3039b37e0d56525a0a8 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\ProcessSignal\\Exception;

use Mautic\\CoreBundle\\ProcessSignal\\ProcessSignalService;

class SignalCaughtException extends \\Exception
{
    public function __construct(int \$signal = ProcessSignalService::SIGTERM)
    {
        parent::__construct(sprintf('Signal received: \"%d\"', \$signal), \$signal);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/ProcessSignal/Exception/SignalCaughtException.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/ProcessSignal/Exception/SignalCaughtException.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/ProcessSignal/Exception/SignalCaughtException.php");
    }
}
